@@ -9,7 +9,6 @@ class Brazil(WesternCalendar):
     "Brazil"
     FIXED_HOLIDAYS = WesternCalendar.FIXED_HOLIDAYS + (
         (4, 21, "Tiradentes' Day"),
-        (5, 1, "Labour Day"),
         (9, 7, "Independence Day"),
         (10, 12, "Our Lady of Aparecida"),
         (11, 2, "All Souls' Day"),
@@ -21,6 +20,8 @@ class Brazil(WesternCalendar):
     sao_pedro_label = "São Pedro"
     include_sao_joao = False
     sao_joao_label = "São João"
+    # Civil holidays
+    include_labour_day = True
     include_servidor_publico = False
     servidor_publico_label = "Dia do Servidor Público"
     # Consciência Negra day
@@ -29,8 +30,12 @@ class Brazil(WesternCalendar):
     # The most common is November, 20th
     consciencia_negra_day = (11, 20)
     consciencia_negra_label = "Consciência Negra"
-    include_nossa_senhora_conceicao = False
+
+    # Christian holidays
     include_easter_sunday = True
+    # Dia de Nossa Senhora da Conceição is the Immaculate Conception.
+    include_immaculate_conception = False
+    immaculate_conception_label = "Dia de Nossa Senhora da Conceição"
 
     def get_variable_days(self, year):
         days = super().get_variable_days(year)
@@ -47,10 +52,6 @@ class Brazil(WesternCalendar):
             days.append(
                 (date(year, month, day), self.consciencia_negra_label)
             )
-        if self.include_nossa_senhora_conceicao:
-            days.append(
-                (date(year, 12, 8), "Dia de Nossa Senhora da Conceição")
-            )
         return days
 
 
@@ -97,7 +98,7 @@ class BrazilAmazonas(Brazil):
         (9, 5, "Elevação do Amazonas á categoria de província"),
     )
     include_consciencia_negra = True
-    include_nossa_senhora_conceicao = True
+    include_immaculate_conception = True
 
 
 @iso_register('BR-BA')
@@ -145,7 +146,7 @@ class BrazilMaranhao(Brazil):
     FIXED_HOLIDAYS = Brazil.FIXED_HOLIDAYS + (
         (7, 28, "Adesão do Maranhão á independência do Brasil"),
     )
-    include_nossa_senhora_conceicao = True
+    include_immaculate_conception = True
 
 
 @iso_register('BR-MG')
@@ -177,7 +178,7 @@ class BrazilPara(Brazil):
     FIXED_HOLIDAYS = Brazil.FIXED_HOLIDAYS + (
         (8, 15, "Adesão do Grão-Pará á independência do Brasil"),
     )
-    include_nossa_senhora_conceicao = True
+    include_immaculate_conception = True
 
 
 @iso_register('BR-PB')
@@ -228,7 +229,7 @@ class BrazilRioDeJaneiro(Brazil):
     servidor_publico_label = "Dia do Funcionário Público"
     include_consciencia_negra = True
     consciencia_negra_label = "Dia da Consciência Negra"
-    include_nossa_senhora_conceicao = True
+    include_immaculate_conception = True
 
     def get_dia_do_comercio(self, year):
         """
@@ -369,7 +370,7 @@ class BrazilGuarapariCity(BrazilEspiritoSanto):
     include_sao_pedro = True
     include_consciencia_negra = True
     consciencia_negra_day = (11, 29)
-    include_nossa_senhora_conceicao = True
+    include_immaculate_conception = True
 
 
 class BrazilSerraCity(BrazilEspiritoSanto):
@@ -384,7 +385,7 @@ class BrazilSerraCity(BrazilEspiritoSanto):
     include_good_friday = True
     good_friday_label = "Paixão do Cristo"
     include_sao_pedro = True
-    include_nossa_senhora_conceicao = True
+    include_immaculate_conception = True
 
     def get_variable_days(self, year):
         days = super().get_variable_days(year)
